[![Documentation Status](https://readthedocs.org/projects/tufte/badge/?version=latest)](https://tufte.readthedocs.io/en/latest/?badge=latest)
[![CI](https://github.com/hsteinshiromoto/tufte/actions/workflows/ci.yml/badge.svg)](https://github.com/hsteinshiromoto/tufte/actions/workflows/ci.yml)
[![Github tag](https://badgen.net/github/tag/hsteinshiromoto/tufte)](https://github.com/hsteinshiromoto/tufte/tags/)
[![PyPI version](https://badge.fury.io/py/tufte.svg)](https://badge.fury.io/py/tufte)
[![DOI](https://zenodo.org/badge/130211437.svg)](https://zenodo.org/badge/latestdoi/130211437)

# 1. Tufte

A Tufte-inspired style for plotting data.

# 2. Table of Contents

- [1. Tufte](#1-tufte)
- [2. Table of Contents](#2-table-of-contents)
- [3. Installation](#3-installation)

# 3. Installation

`$ pip install tufte`